# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlTypeDrempel import KlTypeDrempel
from ...Datatypes.KlVastAanslagmateriaal import KlVastAanslagmateriaal
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Drempel(AIMNaamObject, LijnGeometrie):
    """Vaste opstand op de bodem van het constructiehoofd over de breedte van de constructie voor de waterdichting en/of krachtoverdracht van de beweegbare waterkerende constructie (m.u.v. roldeuren)."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Drempel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElementSluisStuw', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluishoofd', direction='o')  # o = direction: outgoing

        self._typeDrempel = OTLAttribuut(field=KlTypeDrempel,
                                         naam='typeDrempel',
                                         label='type drempel',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Drempel.typeDrempel',
                                         definition='Vaste opstand op de bodem van het constructiehoofd over de breedte van de constructie voor de waterdichting en/of krachtoverdracht van de beweegbare waterkerende constructie (m.u.v. roldeuren).',
                                         owner=self)

        self._vastAanslagmateriaal = OTLAttribuut(field=KlVastAanslagmateriaal,
                                                  naam='vastAanslagmateriaal',
                                                  label='vast aanslagmateriaal',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Drempel.vastAanslagmateriaal',
                                                  definition='De verschillende mogelijkheden m.b.t. het materiaal van de aanslag',
                                                  owner=self)

    @property
    def typeDrempel(self) -> str:
        """Vaste opstand op de bodem van het constructiehoofd over de breedte van de constructie voor de waterdichting en/of krachtoverdracht van de beweegbare waterkerende constructie (m.u.v. roldeuren)."""
        return self._typeDrempel.get_waarde()

    @typeDrempel.setter
    def typeDrempel(self, value):
        self._typeDrempel.set_waarde(value, owner=self)

    @property
    def vastAanslagmateriaal(self) -> str:
        """De verschillende mogelijkheden m.b.t. het materiaal van de aanslag"""
        return self._vastAanslagmateriaal.get_waarde()

    @vastAanslagmateriaal.setter
    def vastAanslagmateriaal(self, value):
        self._vastAanslagmateriaal.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.BegroeidVoorkomen import BegroeidVoorkomen
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class InvasieveExoten(BegroeidVoorkomen, PuntGeometrie, VlakGeometrie):
    """Invasieve exoten zijn planten die door menselijk handelen buiten hun natuurlijk verspreidingsgebied ('exoot') gebracht zijn en die in staat zijn zich op een natuurlijke wijze, al dan niet massaal, te verspreiden en hierbij schade (biodiversiteit, economisch, volksgezondheid) kunnen aanrichten ('invasief')."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#InvasieveExoten'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftBeheer', target='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#BeheerExoten', direction='o')  # o = direction: outgoing



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlSlagrichting import KlSlagrichting
from ...Datatypes.KlVetType import KlVetType
from ...Datatypes.KwantWrdInMegaPascal import KwantWrdInMegaPascal, KwantWrdInMegaPascalWaarden
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from ...Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Staalkabel(TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een kabel die bestaat uit meerdere strengen, waarbij elke streng afzonderlijk is opgebouwd uit gewikkelde staaldraden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Staalkabel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aangrijpingsstoel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Evenaar', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kabelspanner', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kabeltrommel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RegelbaarTegengewicht', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VastTegengewicht', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kabelbewegingsmechanisme', direction='o')  # o = direction: outgoing

        self._diameterKabel = OTLAttribuut(field=KwantWrdInMillimeter,
                                           naam='diameterKabel',
                                           label='diameter kabel',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Staalkabel.diameterKabel',
                                           definition='De diameter van de staalkabel, uitgedrukt in millimeter.',
                                           owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Staalkabel.lengte',
                                    definition='De lengte van de staalkabel, uitgedrukt in meter.',
                                    owner=self)

        self._slagrichting = OTLAttribuut(field=KlSlagrichting,
                                          naam='slagrichting',
                                          label='slagrichting',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Staalkabel.slagrichting',
                                          definition='De slagrichting geeft aan op welke wijze de strengen rond de kern worden geslagen.',
                                          owner=self)

        self._treksterkte = OTLAttribuut(field=KwantWrdInMegaPascal,
                                         naam='treksterkte',
                                         label='treksterkte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Staalkabel.treksterkte',
                                         definition='De treksterkte van een staalkabel is de maximale trekkracht die de staalkabel aan kan.',
                                         owner=self)

        self._typeVet = OTLAttribuut(field=KlVetType,
                                     naam='typeVet',
                                     label='type vet',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Staalkabel.typeVet',
                                     definition='Geeft aan met welk type vet de staalkabel gesmeerd is.',
                                     owner=self)

    @property
    def diameterKabel(self) -> KwantWrdInMillimeterWaarden:
        """De diameter van de staalkabel, uitgedrukt in millimeter."""
        return self._diameterKabel.get_waarde()

    @diameterKabel.setter
    def diameterKabel(self, value):
        self._diameterKabel.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De lengte van de staalkabel, uitgedrukt in meter."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def slagrichting(self) -> str:
        """De slagrichting geeft aan op welke wijze de strengen rond de kern worden geslagen."""
        return self._slagrichting.get_waarde()

    @slagrichting.setter
    def slagrichting(self, value):
        self._slagrichting.set_waarde(value, owner=self)

    @property
    def treksterkte(self) -> KwantWrdInMegaPascalWaarden:
        """De treksterkte van een staalkabel is de maximale trekkracht die de staalkabel aan kan."""
        return self._treksterkte.get_waarde()

    @treksterkte.setter
    def treksterkte(self, value):
        self._treksterkte.set_waarde(value, owner=self)

    @property
    def typeVet(self) -> str:
        """Geeft aan met welk type vet de staalkabel gesmeerd is."""
        return self._typeVet.get_waarde()

    @typeVet.setter
    def typeVet(self, value):
        self._typeVet.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlDetectiecameraModelnaam(KeuzelijstField):
    """Keuzelijst met modelnamen voor Detectiecamera."""
    naam = 'KlDetectiecameraModelnaam'
    label = 'Detectiecamera modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlDetectiecameraModelnaam'
    definition = 'Keuzelijst met modelnamen voor Detectiecamera.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlDetectiecameraModelnaam'
    options = {
        'thermicam-ai-345': KeuzelijstWaarde(invulwaarde='thermicam-ai-345',
                                             label='ThermiCam AI-345',
                                             status='ingebruik',
                                             definitie='ThermiCam AI-345',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDetectiecameraModelnaam/thermicam-ai-345'),
        'thermicam-ai-635': KeuzelijstWaarde(invulwaarde='thermicam-ai-635',
                                             label='ThermiCam AI-635',
                                             status='ingebruik',
                                             definitie='ThermiCam AI-635',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDetectiecameraModelnaam/thermicam-ai-635'),
        'thermicam-ai-690': KeuzelijstWaarde(invulwaarde='thermicam-ai-690',
                                             label='ThermiCam AI-690',
                                             status='ingebruik',
                                             definitie='ThermiCam AI-690',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDetectiecameraModelnaam/thermicam-ai-690'),
        'thermicam2-390': KeuzelijstWaarde(invulwaarde='thermicam2-390',
                                           label='ThermiCam2 390',
                                           status='ingebruik',
                                           definitie='ThermiCam2 390',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDetectiecameraModelnaam/thermicam2-390'),
        'traficam-ai-narrow': KeuzelijstWaarde(invulwaarde='traficam-ai-narrow',
                                               label='TrafiCam AI – Narrow',
                                               status='ingebruik',
                                               definitie='TrafiCam AI – Narrow',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDetectiecameraModelnaam/traficam-ai-narrow'),
        'traficam-ai-wide': KeuzelijstWaarde(invulwaarde='traficam-ai-wide',
                                             label='TrafiCam AI - Wide',
                                             status='ingebruik',
                                             definitie='TrafiCam AI - Wide',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDetectiecameraModelnaam/traficam-ai-wide'),
        'traficam-x-stream2-bpl-narrow': KeuzelijstWaarde(invulwaarde='traficam-x-stream2-bpl-narrow',
                                                          label='TrafiCam X-stream2 BPL Narrow',
                                                          status='ingebruik',
                                                          definitie='TrafiCam X-stream2 BPL Narrow',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDetectiecameraModelnaam/traficam-x-stream2-bpl-narrow'),
        'traficam-x-stream2-bpl-wide': KeuzelijstWaarde(invulwaarde='traficam-x-stream2-bpl-wide',
                                                        label='TrafiCam X-stream2 BPL Wide',
                                                        status='ingebruik',
                                                        definitie='TrafiCam X-stream2 BPL Wide',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDetectiecameraModelnaam/traficam-x-stream2-bpl-wide'),
        'traficam2-narrow-angle': KeuzelijstWaarde(invulwaarde='traficam2-narrow-angle',
                                                   label='TrafiCam2 Narrow Angle',
                                                   status='ingebruik',
                                                   definitie='TrafiCam2 Narrow Angle',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDetectiecameraModelnaam/traficam2-narrow-angle'),
        'traficam2-wide-angle': KeuzelijstWaarde(invulwaarde='traficam2-wide-angle',
                                                 label='TrafiCam2 Wide Angle',
                                                 status='ingebruik',
                                                 definitie='TrafiCam2 Wide Angle',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDetectiecameraModelnaam/traficam2-wide-angle')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlUPSModelnaam(KeuzelijstField):
    """De modelnaam van de UPS."""
    naam = 'KlUPSModelnaam'
    label = 'UPS modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlUPSModelnaam'
    definition = 'De modelnaam van de UPS.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlUPSModelnaam'
    options = {
        'other': KeuzelijstWaarde(invulwaarde='other',
                                  label='Other',
                                  status='ingebruik',
                                  definitie='Deze optie mag uitsluitend TIJDELIJK worden gebruikt en enkel tot de juiste gegevens beschikbaar zijn. Misbruik van deze optie leidt tot verminderde datakwaliteit.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlUPSModelnaam/other'),
        'ps15': KeuzelijstWaarde(invulwaarde='ps15',
                                 label='PS15',
                                 status='ingebruik',
                                 definitie='PS15',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlUPSModelnaam/ps15'),
        'quint4-ps-1ac-24dc-2-5-pt': KeuzelijstWaarde(invulwaarde='quint4-ps-1ac-24dc-2-5-pt',
                                                      label='QUINT4-PS-1AC-24DC-2.5-PT',
                                                      status='ingebruik',
                                                      definitie='QUINT4-PS-1AC-24DC-2.5-PT',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlUPSModelnaam/quint4-ps-1ac-24dc-2-5-pt'),
        'smt750i': KeuzelijstWaarde(invulwaarde='smt750i',
                                    label='SMT750I',
                                    status='ingebruik',
                                    definitie='SMT750I',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlUPSModelnaam/smt750i'),
        'smx1500rmi2u': KeuzelijstWaarde(invulwaarde='smx1500rmi2u',
                                         label='SMX1500RMI2U',
                                         status='ingebruik',
                                         definitie='SMX1500RMI2U',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlUPSModelnaam/smx1500rmi2u'),
        'smx750i': KeuzelijstWaarde(invulwaarde='smx750i',
                                    label='SMX750I',
                                    status='ingebruik',
                                    definitie='SMX750I',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlUPSModelnaam/smx750i'),
        'su1400rmxlib3u': KeuzelijstWaarde(invulwaarde='su1400rmxlib3u',
                                           label='SU1400RMXLIB3U',
                                           status='ingebruik',
                                           definitie='SU1400RMXLIB3U',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlUPSModelnaam/su1400rmxlib3u'),
        'su750rm': KeuzelijstWaarde(invulwaarde='su750rm',
                                    label='SU750RM',
                                    status='ingebruik',
                                    definitie='SU750RM',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlUPSModelnaam/su750rm'),
        'ub10-241': KeuzelijstWaarde(invulwaarde='ub10-241',
                                     label='UB10.241',
                                     status='ingebruik',
                                     definitie='UB10.241',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlUPSModelnaam/ub10-241')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.ConstructiefObject import ConstructiefObject
from ...Classes.Abstracten.DetaiplanObject import DetaiplanObject
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Randprofiel(ConstructiefObject, DetaiplanObject, PuntGeometrie, LijnGeometrie):
    """Profiel ter afwerking en versterking van de rand. Deze kan uitgevoerd worden in verschillende materialen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Randprofiel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kesp', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StalenProfiel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kokerruimte', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kelderlandhoofd', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kelderpijler', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koker', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokersectie', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Landhoofd', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pijler', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding', direction='i')  # i = direction: incoming

        self._lopendeMeter = OTLAttribuut(field=KwantWrdInMeter,
                                          naam='lopendeMeter',
                                          label='lopende meter',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Randprofiel.lopendeMeter',
                                          definition='Lopende meter van het randprofiel.',
                                          owner=self)

    @property
    def lopendeMeter(self) -> KwantWrdInMeterWaarden:
        """Lopende meter van het randprofiel."""
        return self._lopendeMeter.get_waarde()

    @lopendeMeter.setter
    def lopendeMeter(self, value):
        self._lopendeMeter.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlDwarseMarkeringCode(KeuzelijstField):
    """Codes van de dwarse markering."""
    naam = 'KlDwarseMarkeringCode'
    label = 'Dwarse markering code'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlDwarseMarkeringCode'
    definition = 'Codes van de dwarse markering.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlDwarseMarkeringCode'
    options = {
        'DAMBRD': KeuzelijstWaarde(invulwaarde='DAMBRD',
                                   label='DAMBRD',
                                   status='ingebruik',
                                   definitie='Dambord',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/DAMBRD'),
        'DREMPEL-1.2': KeuzelijstWaarde(invulwaarde='DREMPEL-1.2',
                                        label='DREMPEL 1.2',
                                        status='ingebruik',
                                        definitie='Verkeersdrempel markering',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/DREMPEL-1.2'),
        'DRH-fiets-(0.3)': KeuzelijstWaarde(invulwaarde='DRH-fiets-(0.3)',
                                            label='DRH fiets (0.3)',
                                            status='ingebruik',
                                            definitie='Driehoek fiets',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/DRH-fiets-(0.3)'),
        'DRH-std-(0.7)': KeuzelijstWaarde(invulwaarde='DRH-std-(0.7)',
                                          label='DRH std (0.7)',
                                          status='ingebruik',
                                          definitie='Driehoek standaard',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/DRH-std-(0.7)'),
        'FLV': KeuzelijstWaarde(invulwaarde='FLV',
                                label='FLV',
                                status='ingebruik',
                                definitie='Verbindingsmarkering voor fietsers.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/FLV'),
        'FOP': KeuzelijstWaarde(invulwaarde='FOP',
                                label='FOP',
                                status='ingebruik',
                                definitie='Fietsoversteekplaats met blokken',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/FOP'),
        'PARKEER': KeuzelijstWaarde(invulwaarde='PARKEER',
                                    label='PARKEER',
                                    status='ingebruik',
                                    definitie='Parkeerstrook',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/PARKEER'),
        'RIBBELSTROOK---AFREMMINGSSTREPEN': KeuzelijstWaarde(invulwaarde='RIBBELSTROOK---AFREMMINGSSTREPEN',
                                                             label='RIBBELSTROOK - AFREMMINGSSTREPEN',
                                                             status='ingebruik',
                                                             definitie='Afremmingsstreep',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/RIBBELSTROOK---AFREMMINGSSTREPEN'),
        'STOPSTRP': KeuzelijstWaarde(invulwaarde='STOPSTRP',
                                     label='STOPSTRP',
                                     status='ingebruik',
                                     definitie='Code voor de stopstreep',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/STOPSTRP'),
        'STOPSTRP-OFOS': KeuzelijstWaarde(invulwaarde='STOPSTRP-OFOS',
                                          label='STOPSTRP-OFOS',
                                          status='ingebruik',
                                          definitie='Code voor de stopstreep OFOS',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/STOPSTRP-OFOS'),
        'VOP-(3)': KeuzelijstWaarde(invulwaarde='VOP-(3)',
                                    label='VOP (3)',
                                    status='ingebruik',
                                    definitie='Voetgangers-oversteekplaats (3 meter)',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/VOP-(3)'),
        'VOP-(4)': KeuzelijstWaarde(invulwaarde='VOP-(4)',
                                    label='VOP (4)',
                                    status='ingebruik',
                                    definitie='Voetgangers-oversteekplaats (4 meter)',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/VOP-(4)'),
        'VOP-(var)': KeuzelijstWaarde(invulwaarde='VOP-(var)',
                                      label='VOP (var)',
                                      status='ingebruik',
                                      definitie='Voetgangers-oversteekplaats (te meten)',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/VOP-(var)'),
        'VVA-0.4-(0.6)': KeuzelijstWaarde(invulwaarde='VVA-0.4-(0.6)',
                                          label='VVA 0.4 (0.6)',
                                          status='ingebruik',
                                          definitie='Verdrijvingsvlak (40 % opp. v.h. vlak)',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/VVA-0.4-(0.6)'),
        'VVA-1-(2)': KeuzelijstWaarde(invulwaarde='VVA-1-(2)',
                                      label='VVA 1 (2)',
                                      status='ingebruik',
                                      definitie='Verdrijvingsvlak (33 % opp. v.h. vlak)',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDwarseMarkeringCode/VVA-1-(2)')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Signalisatie import Signalisatie
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.KlDivergentiepuntbebakeningselementType import KlDivergentiepuntbebakeningselementType
from ...Datatypes.KlFolieType import KlFolieType
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Divergentiepuntbebakeningselement(Signalisatie, AIMObject, PuntGeometrie):
    """Een constructie met als doel de zichtbaarheid van het divergentiepunt te vergroten."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Divergentiepuntbebakeningselement'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BitumineuzeLaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RetroreflecterendeFolie', direction='u')  # u = unidirectional

        self._folietype = OTLAttribuut(field=KlFolieType,
                                       naam='folietype',
                                       label='folietype',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Divergentiepuntbebakeningselement.folietype',
                                       definition='Het type folie dat bevestigd is aan het Divergentiepuntbebakeningselement.',
                                       owner=self)

        self._type = OTLAttribuut(field=KlDivergentiepuntbebakeningselementType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Divergentiepuntbebakeningselement.type',
                                  definition='De vormen van het divergentiepuntbebakeningselement.',
                                  owner=self)

    @property
    def folietype(self) -> str:
        """Het type folie dat bevestigd is aan het Divergentiepuntbebakeningselement."""
        return self._folietype.get_waarde()

    @folietype.setter
    def folietype(self, value):
        self._folietype.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """De vormen van het divergentiepuntbebakeningselement."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.KlWeegcomputerMerk import KlWeegcomputerMerk
from ...Datatypes.KlWeegcomputerModelnaam import KlWeegcomputerModelnaam
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Weegcomputer(AIMObject, PuntGeometrie):
    """Een verwerkingseenheid met als input de weeggegevens van de weegcellen en output het gewicht."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegcomputer'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IndoorKast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegcel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring', direction='i')  # i = direction: incoming

        self._checksum = OTLAttribuut(field=StringField,
                                      naam='checksum',
                                      label='checksum',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegcomputer.checksum',
                                      definition='Een tekenreeks waarmee kan gecontroleerd worden of de vooropgestelde waardes van paramaters van de weegcomputer correct en ongewijzigd gebleven zijn.',
                                      owner=self)

        self._merk = OTLAttribuut(field=KlWeegcomputerMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegcomputer.merk',
                                  definition='Merknaam van het toestel volgens de fabrikant.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlWeegcomputerModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegcomputer.modelnaam',
                                       definition='Modelnaam van het toestel volgens de fabrikant.',
                                       owner=self)

        self._serienummer = OTLAttribuut(field=StringField,
                                         naam='serienummer',
                                         label='serienummer',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegcomputer.serienummer',
                                         definition='Unieke identificatie van het toestel, toegekend door de fabrikant.',
                                         owner=self)

    @property
    def checksum(self) -> str:
        """Een tekenreeks waarmee kan gecontroleerd worden of de vooropgestelde waardes van paramaters van de weegcomputer correct en ongewijzigd gebleven zijn."""
        return self._checksum.get_waarde()

    @checksum.setter
    def checksum(self, value):
        self._checksum.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Merknaam van het toestel volgens de fabrikant."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """Modelnaam van het toestel volgens de fabrikant."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def serienummer(self) -> str:
        """Unieke identificatie van het toestel, toegekend door de fabrikant."""
        return self._serienummer.get_waarde()

    @serienummer.setter
    def serienummer(self, value):
        self._serienummer.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Tegenmateriaal(TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een slijtageongevoelig onderdeel dat direct contact maakt met een ander bewegend of stilstaand onderdeel binnen een glijgeleiding. Het betreft het harde deel van de glijgeleiding en dient om krachten over te brengen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tegenmateriaal'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Glijgeleiding', direction='o')  # o = direction: outgoing



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Geleidingsmechanisme import Geleidingsmechanisme
from ...Classes.Abstracten.StaalsoortObject import StaalsoortObject
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KwantWrdInTon import KwantWrdInTon, KwantWrdInTonWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Onderrolwagen(Geleidingsmechanisme, StaalsoortObject, AIMNaamObject):
    """Dit object is verbonden met de roldeur en bevat wielen die over de onderste looprails van de constructie rijden, waardoor de deur horizontaal kan bewegen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Onderrolwagen'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Glijgeleiding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Rolgeleiding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Bufferinstallatie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Railconstructie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rol', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rolwagenchassis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wiel', direction='i')  # i = direction: incoming

        self._gewicht = OTLAttribuut(field=KwantWrdInTon,
                                     naam='gewicht',
                                     label='gewicht',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Onderrolwagen.gewicht',
                                     definition='Het gewicht van de wagen, uitgedrukt in kilogram.',
                                     owner=self)

        self._heeftSchraper = OTLAttribuut(field=BooleanField,
                                           naam='heeftSchraper',
                                           label='heeft schraper',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Onderrolwagen.heeftSchraper',
                                           definition='Geeft aan of de onderrolwagen een schraper heeft of niet.',
                                           owner=self)

        self._heeftTrekoog = OTLAttribuut(field=BooleanField,
                                          naam='heeftTrekoog',
                                          label='heeft trekoog',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Onderrolwagen.heeftTrekoog',
                                          definition='Geeft aan of de onderrolwagen een trekoog heeft of niet.',
                                          owner=self)

    @property
    def gewicht(self) -> KwantWrdInTonWaarden:
        """Het gewicht van de wagen, uitgedrukt in kilogram."""
        return self._gewicht.get_waarde()

    @gewicht.setter
    def gewicht(self, value):
        self._gewicht.set_waarde(value, owner=self)

    @property
    def heeftSchraper(self) -> bool:
        """Geeft aan of de onderrolwagen een schraper heeft of niet."""
        return self._heeftSchraper.get_waarde()

    @heeftSchraper.setter
    def heeftSchraper(self, value):
        self._heeftSchraper.set_waarde(value, owner=self)

    @property
    def heeftTrekoog(self) -> bool:
        """Geeft aan of de onderrolwagen een trekoog heeft of niet."""
        return self._heeftTrekoog.get_waarde()

    @heeftTrekoog.setter
    def heeftTrekoog(self, value):
        self._heeftTrekoog.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.VRModuleMetFirmware import VRModuleMetFirmware


# Generated with OTLClassCreator. To modify: extend, do not edit
class VRLuskaart(VRModuleMetFirmware):
    """Kaart die instaat voor het verwerken van de informatie uit de lussen en voor het doorgeven van die informatie naar de besturingskaart."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRLuskaart'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()



# coding=utf-8
from ...Classes.Abstracten.StaalsoortObject import StaalsoortObject
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Schakel(StaalsoortObject, TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een verbindingsonderdeel dat wordt gebruikt in kettingen of andere systemen om krachten over te brengen of bewegende delen aan elkaar te koppelen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schakel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Halsbeugelmechanisme', direction='o')  # o = direction: outgoing



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlIOKaartMerk(KeuzelijstField):
    """Lijst van mogelijke merken voor IO-kaarten."""
    naam = 'KlIOKaartMerk'
    label = 'IO-kaart merken'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlIOKaartMerk'
    definition = 'Lijst van mogelijke merken voor IO-kaarten.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlIOKaartMerk'
    options = {
        'phoenix-contact': KeuzelijstWaarde(invulwaarde='phoenix-contact',
                                            label='Phoenix Contact',
                                            status='ingebruik',
                                            definitie='Phoenix Contact',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIOKaartMerk/phoenix-contact'),
        'vaisala': KeuzelijstWaarde(invulwaarde='vaisala',
                                    label='Vaisala',
                                    status='ingebruik',
                                    definitie='Vaisala',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIOKaartMerk/vaisala')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSegmentcontrollerMerk(KeuzelijstField):
    """De mogelijke merken voor een segmentcontroller."""
    naam = 'KlSegmentcontrollerMerk'
    label = 'Segmentcontroller merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSegmentcontrollerMerk'
    definition = 'De mogelijke merken voor een segmentcontroller.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSegmentcontrollerMerk'
    options = {
        'lacroix': KeuzelijstWaarde(invulwaarde='lacroix',
                                    label='Lacroix',
                                    status='ingebruik',
                                    definitie='Lacroix',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSegmentcontrollerMerk/lacroix'),
        'smartnodes': KeuzelijstWaarde(invulwaarde='smartnodes',
                                       label='SmartNodes',
                                       status='ingebruik',
                                       definitie='SmartNodes',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSegmentcontrollerMerk/smartnodes')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlAlgInspecteerbaarheid import KlAlgInspecteerbaarheid
from ...Datatypes.KlTypeBallast import KlTypeBallast
from ...Datatypes.KwantWrdInKubiekeMeter import KwantWrdInKubiekeMeter, KwantWrdInKubiekeMeterWaarden
from ...Datatypes.KwantWrdInTon import KwantWrdInTon, KwantWrdInTonWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Ballastcompartiment(AIMNaamObject, VlakGeometrie):
    """Waterdichte ruimte in een beweegbare of tijdelijke waterkerende constructie alsook vlottende bolder gevuld met water en/of (pers)lucht."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ballastcompartiment'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Toegangsluik', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Toegangsvoorziening', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#BeweegbareWaterkerendeConstructie', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#TijdelijkeWaterkerendeConstructie', direction='o')  # o = direction: outgoing

        self._gewicht = OTLAttribuut(field=KwantWrdInTon,
                                     naam='gewicht',
                                     label='gewicht',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ballastcompartiment.gewicht',
                                     definition='Het gewicht van de ballast uitgedrukt in ton.',
                                     owner=self)

        self._heeftOntluchtingsgat = OTLAttribuut(field=BooleanField,
                                                  naam='heeftOntluchtingsgat',
                                                  label='heeft ontluchtingsgat',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ballastcompartiment.heeftOntluchtingsgat',
                                                  definition='Geeft aan of er een ontluchtingsgat aanwezig is.',
                                                  owner=self)

        self._heeftPeilbuis = OTLAttribuut(field=BooleanField,
                                           naam='heeftPeilbuis',
                                           label='heeft peilbuis',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ballastcompartiment.heeftPeilbuis',
                                           definition='Geeft aan of er een peilbuis aanwezig is.',
                                           owner=self)

        self._isInspecteerbaar = OTLAttribuut(field=KlAlgInspecteerbaarheid,
                                              naam='isInspecteerbaar',
                                              label='is luchtkist of ballastcompartiment inspecteerbaar?',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ballastcompartiment.isInspecteerbaar',
                                              definition='Geeft de verschillende mogelijkheden aan om te weten of de luchtkisten of ballastcompartimenten inspecteerbaar zijn.',
                                              owner=self)

        self._isRegelbaar = OTLAttribuut(field=BooleanField,
                                         naam='isRegelbaar',
                                         label='is regelbaar',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ballastcompartiment.isRegelbaar',
                                         definition='Geeft aan of de ballast regelbaar is of niet.',
                                         owner=self)

        self._typeBallast = OTLAttribuut(field=KlTypeBallast,
                                         naam='typeBallast',
                                         label='type ballast',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ballastcompartiment.typeBallast',
                                         definition='Het specifieke materiaal dat wordt gebruikt als ballast in het ballastcompartiment.',
                                         owner=self)

        self._volume = OTLAttribuut(field=KwantWrdInKubiekeMeter,
                                    naam='volume',
                                    label='volume',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ballastcompartiment.volume',
                                    definition='Het maximale (te vullen) volume van de ballastcompartiment uitgedrukt in kubieke meter.',
                                    owner=self)

    @property
    def gewicht(self) -> KwantWrdInTonWaarden:
        """Het gewicht van de ballast uitgedrukt in ton."""
        return self._gewicht.get_waarde()

    @gewicht.setter
    def gewicht(self, value):
        self._gewicht.set_waarde(value, owner=self)

    @property
    def heeftOntluchtingsgat(self) -> bool:
        """Geeft aan of er een ontluchtingsgat aanwezig is."""
        return self._heeftOntluchtingsgat.get_waarde()

    @heeftOntluchtingsgat.setter
    def heeftOntluchtingsgat(self, value):
        self._heeftOntluchtingsgat.set_waarde(value, owner=self)

    @property
    def heeftPeilbuis(self) -> bool:
        """Geeft aan of er een peilbuis aanwezig is."""
        return self._heeftPeilbuis.get_waarde()

    @heeftPeilbuis.setter
    def heeftPeilbuis(self, value):
        self._heeftPeilbuis.set_waarde(value, owner=self)

    @property
    def isInspecteerbaar(self) -> str:
        """Geeft de verschillende mogelijkheden aan om te weten of de luchtkisten of ballastcompartimenten inspecteerbaar zijn."""
        return self._isInspecteerbaar.get_waarde()

    @isInspecteerbaar.setter
    def isInspecteerbaar(self, value):
        self._isInspecteerbaar.set_waarde(value, owner=self)

    @property
    def isRegelbaar(self) -> bool:
        """Geeft aan of de ballast regelbaar is of niet."""
        return self._isRegelbaar.get_waarde()

    @isRegelbaar.setter
    def isRegelbaar(self, value):
        self._isRegelbaar.set_waarde(value, owner=self)

    @property
    def typeBallast(self) -> str:
        """Het specifieke materiaal dat wordt gebruikt als ballast in het ballastcompartiment."""
        return self._typeBallast.get_waarde()

    @typeBallast.setter
    def typeBallast(self, value):
        self._typeBallast.set_waarde(value, owner=self)

    @property
    def volume(self) -> KwantWrdInKubiekeMeterWaarden:
        """Het maximale (te vullen) volume van de ballastcompartiment uitgedrukt in kubieke meter."""
        return self._volume.get_waarde()

    @volume.setter
    def volume(self, value):
        self._volume.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.LinkendElement import LinkendElement
from ...Classes.Abstracten.OmhullendeInrichting import OmhullendeInrichting
from ...Datatypes.KlAansluitstukMateriaal import KlAansluitstukMateriaal
from ...Datatypes.KlHulpstukType import KlHulpstukType
from ...Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Hulpstuk(LinkendElement, OmhullendeInrichting, PuntGeometrie):
    """Stukken die zorgen voor verbindingen tussen buizen en/of leidingen om bv. van richting te veranderen,te verlengen,te verlopen van diameter,meerdere buizen op mekaar aan te sluiten,..."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulpstuk'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Beschermbuis', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Brandvoorziening', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LinkendElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#PutRelatie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#WaterloopRelatie', direction='i')  # i = direction: incoming

        self._inwendigeDiameter = OTLAttribuut(field=KwantWrdInMillimeter,
                                               naam='inwendigeDiameter',
                                               label='inwendige diameter',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulpstuk.inwendigeDiameter',
                                               kardinaliteit_max='*',
                                               definition='De diameter van de binnenzijde van het hulpstuk in millimeter.',
                                               owner=self)

        self._materiaal = OTLAttribuut(field=KlAansluitstukMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulpstuk.materiaal',
                                       definition='Het materiaal waaruit het hulpstuk vervaardigd is.',
                                       owner=self)

        self._type = OTLAttribuut(field=KlHulpstukType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulpstuk.type',
                                  definition='Het type van het hulpstuk.',
                                  owner=self)

        self._uitwendigeDiameter = OTLAttribuut(field=KwantWrdInMillimeter,
                                                naam='uitwendigeDiameter',
                                                label='uitwendige diameter',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulpstuk.uitwendigeDiameter',
                                                kardinaliteit_max='*',
                                                definition='De diameter van de buitenzijde van het hulpstuk in millimeter.',
                                                owner=self)

    @property
    def inwendigeDiameter(self) -> List[KwantWrdInMillimeterWaarden]:
        """De diameter van de binnenzijde van het hulpstuk in millimeter."""
        return self._inwendigeDiameter.get_waarde()

    @inwendigeDiameter.setter
    def inwendigeDiameter(self, value):
        self._inwendigeDiameter.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal waaruit het hulpstuk vervaardigd is."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type van het hulpstuk."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)

    @property
    def uitwendigeDiameter(self) -> List[KwantWrdInMillimeterWaarden]:
        """De diameter van de buitenzijde van het hulpstuk in millimeter."""
        return self._uitwendigeDiameter.get_waarde()

    @uitwendigeDiameter.setter
    def uitwendigeDiameter(self, value):
        self._uitwendigeDiameter.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNetwerkkaartModelnaam(KeuzelijstField):
    """Modelnamen voor Netwerkkaarten."""
    naam = 'KlNetwerkkaartModelnaam'
    label = 'Netwerkkaart modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNetwerkkaartModelnaam'
    definition = 'Modelnamen voor Netwerkkaarten.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNetwerkkaartModelnaam'
    options = {
        'ASC105': KeuzelijstWaarde(invulwaarde='ASC105',
                                   label='ASC105',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ASC105'),
        'ASC108': KeuzelijstWaarde(invulwaarde='ASC108',
                                   label='ASC108',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ASC108'),
        'ASC109': KeuzelijstWaarde(invulwaarde='ASC109',
                                   label='ASC109',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ASC109'),
        'ASC110': KeuzelijstWaarde(invulwaarde='ASC110',
                                   label='ASC110',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ASC110'),
        'CL-DUAL-FC8': KeuzelijstWaarde(invulwaarde='CL-DUAL-FC8',
                                        label='CL-DUAL-FC8',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CL-DUAL-FC8'),
        'CMC410': KeuzelijstWaarde(invulwaarde='CMC410',
                                   label='CMC410',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CMC410'),
        'CMC418': KeuzelijstWaarde(invulwaarde='CMC418',
                                   label='CMC418',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CMC418'),
        'CN-100-C4L': KeuzelijstWaarde(invulwaarde='CN-100-C4L',
                                       label='CN-100-C4L',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-100-C4L'),
        'CN-100-C80': KeuzelijstWaarde(invulwaarde='CN-100-C80',
                                       label='CN-100-C80',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-100-C80'),
        'CN-200-B80': KeuzelijstWaarde(invulwaarde='CN-200-B80',
                                       label='CN-200-B80',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-200-B80'),
        'CN-200-R80': KeuzelijstWaarde(invulwaarde='CN-200-R80',
                                       label='CN-200-R80',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-200-R80'),
        'CN-200-RBS': KeuzelijstWaarde(invulwaarde='CN-200-RBS',
                                       label='CN-200-RBS',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-200-RBS'),
        'CN-C4L-00': KeuzelijstWaarde(invulwaarde='CN-C4L-00',
                                      label='CN-C4L-00',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-C4L-00'),
        'CN-C80-13': KeuzelijstWaarde(invulwaarde='CN-C80-13',
                                      label='CN-C80-13',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-C80-13'),
        'CN-OPS-2': KeuzelijstWaarde(invulwaarde='CN-OPS-2',
                                     label='CN-OPS-2',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-OPS-2'),
        'F10-A90-33': KeuzelijstWaarde(invulwaarde='F10-A90-33',
                                       label='F10-A90-33',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/F10-A90-33'),
        'F10-A90-34': KeuzelijstWaarde(invulwaarde='F10-A90-34',
                                       label='F10-A90-34',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/F10-A90-34'),
        'F10-A90-35': KeuzelijstWaarde(invulwaarde='F10-A90-35',
                                       label='F10-A90-35',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/F10-A90-35'),
        'F10-T90-T31': KeuzelijstWaarde(invulwaarde='F10-T90-T31',
                                        label='F10-T90-T31',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/F10-T90-T31'),
        'F10E-A90-TN': KeuzelijstWaarde(invulwaarde='F10E-A90-TN',
                                        label='F10E-A90-TN',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/F10E-A90-TN'),
        'F10E-T90-TN': KeuzelijstWaarde(invulwaarde='F10E-T90-TN',
                                        label='F10E-T90-TN',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/F10E-T90-TN'),
        'FC4-T90-TN': KeuzelijstWaarde(invulwaarde='FC4-T90-TN',
                                       label='FC4-T90-TN',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/FC4-T90-TN'),
        'LKA146': KeuzelijstWaarde(invulwaarde='LKA146',
                                   label='LKA146',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA146'),
        'LKA39': KeuzelijstWaarde(invulwaarde='LKA39',
                                  label='LKA39',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA39'),
        'LKA412': KeuzelijstWaarde(invulwaarde='LKA412',
                                   label='LKA412',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA412'),
        'LKA48': KeuzelijstWaarde(invulwaarde='LKA48',
                                  label='LKA48',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA48'),
        'LKA53': KeuzelijstWaarde(invulwaarde='LKA53',
                                  label='LKA53',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA53'),
        'LKA58': KeuzelijstWaarde(invulwaarde='LKA58',
                                  label='LKA58',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA58'),
        'LKA62': KeuzelijstWaarde(invulwaarde='LKA62',
                                  label='LKA62',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA62'),
        'M6': KeuzelijstWaarde(invulwaarde='M6',
                               label='M6',
                               status='ingebruik',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/M6'),
        'NTK505DA': KeuzelijstWaarde(invulwaarde='NTK505DA',
                                     label='NTK505DA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK505DA'),
        'NTK505FB': KeuzelijstWaarde(invulwaarde='NTK505FB',
                                     label='NTK505FB',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK505FB'),
        'NTK505QA': KeuzelijstWaarde(invulwaarde='NTK505QA',
                                     label='NTK505QA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK505QA'),
        'NTK505RA': KeuzelijstWaarde(invulwaarde='NTK505RA',
                                     label='NTK505RA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK505RA'),
        'NTK505SB': KeuzelijstWaarde(invulwaarde='NTK505SB',
                                     label='NTK505SB',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK505SB'),
        'NTK505YA': KeuzelijstWaarde(invulwaarde='NTK505YA',
                                     label='NTK505YA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK505YA'),
        'NTK507LD': KeuzelijstWaarde(invulwaarde='NTK507LD',
                                     label='NTK507LD',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK507LD'),
        'NTK507MD': KeuzelijstWaarde(invulwaarde='NTK507MD',
                                     label='NTK507MD',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK507MD'),
        'NTK507NA': KeuzelijstWaarde(invulwaarde='NTK507NA',
                                     label='NTK507NA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK507NA'),
        'NTK507PB': KeuzelijstWaarde(invulwaarde='NTK507PB',
                                     label='NTK507PB',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK507PB'),
        'NTK529AC': KeuzelijstWaarde(invulwaarde='NTK529AC',
                                     label='NTK529AC',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK529AC'),
        'NTK529BA': KeuzelijstWaarde(invulwaarde='NTK529BA',
                                     label='NTK529BA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK529BA'),
        'NTK530PM': KeuzelijstWaarde(invulwaarde='NTK530PM',
                                     label='NTK530PM',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK530PM'),
        'NTK530QA': KeuzelijstWaarde(invulwaarde='NTK530QA',
                                     label='NTK530QA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK530QA'),
        'NTK532DA': KeuzelijstWaarde(invulwaarde='NTK532DA',
                                     label='NTK532DA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK532DA'),
        'NTK536BE': KeuzelijstWaarde(invulwaarde='NTK536BE',
                                     label='NTK536BE',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK536BE'),
        'NTK536FB': KeuzelijstWaarde(invulwaarde='NTK536FB',
                                     label='NTK536FB',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK536FB'),
        'NTK538BM': KeuzelijstWaarde(invulwaarde='NTK538BM',
                                     label='NTK538BM',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK538BM'),
        'NTK539UD': KeuzelijstWaarde(invulwaarde='NTK539UD',
                                     label='NTK539UD',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK539UD'),
        'NTK552AB': KeuzelijstWaarde(invulwaarde='NTK552AB',
                                     label='NTK552AB',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK552AB'),
        'NTK555CA': KeuzelijstWaarde(invulwaarde='NTK555CA',
                                     label='NTK555CA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK555CA'),
        'NTK555NA': KeuzelijstWaarde(invulwaarde='NTK555NA',
                                     label='NTK555NA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK555NA'),
        'NTK555NB': KeuzelijstWaarde(invulwaarde='NTK555NB',
                                     label='NTK555NB',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK555NB'),
        'NULL': KeuzelijstWaarde(invulwaarde='NULL',
                                 label='NULL',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NULL'),
        'Other': KeuzelijstWaarde(invulwaarde='Other',
                                  label='Other',
                                  status='ingebruik',
                                  definitie='Deze optie mag uitsluitend TIJDELIJK worden gebruikt en enkel tot de juiste gegevens beschikbaar zijn. Misbruik van deze optie leidt tot verminderde datakwaliteit.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/Other'),
        'PSM-12V': KeuzelijstWaarde(invulwaarde='PSM-12V',
                                    label='PSM-12V',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/PSM-12V'),
        'RS-10G-4P': KeuzelijstWaarde(invulwaarde='RS-10G-4P',
                                      label='RS-10G-4P',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/RS-10G-4P'),
        'cn-100-a80': KeuzelijstWaarde(invulwaarde='cn-100-a80',
                                       label='CN-100-A80',
                                       status='ingebruik',
                                       definitie='CN-100-A80',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/cn-100-a80'),
        'dcdm-8he': KeuzelijstWaarde(invulwaarde='dcdm-8he',
                                     label='DCDM-8HE',
                                     status='uitgebruik',
                                     definitie='DCDM-8HE',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/dcdm-8he'),
        'dcmd-8he': KeuzelijstWaarde(invulwaarde='dcmd-8he',
                                     label='DCMD-8HE',
                                     status='ingebruik',
                                     definitie='DCMD-8HE',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/dcmd-8he'),
        'ddad-1-34': KeuzelijstWaarde(invulwaarde='ddad-1-34',
                                      label='DDAD-1-34',
                                      status='ingebruik',
                                      definitie='DDAD-1-34',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ddad-1-34'),
        'ddad-2': KeuzelijstWaarde(invulwaarde='ddad-2',
                                   label='DDAD-2',
                                   status='ingebruik',
                                   definitie='DDAD-2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ddad-2'),
        'ddad-2-3536': KeuzelijstWaarde(invulwaarde='ddad-2-3536',
                                        label='DDAD-2-3536',
                                        status='ingebruik',
                                        definitie='DDAD-2-3536',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ddad-2-3536'),
        'ddlt-1-39': KeuzelijstWaarde(invulwaarde='ddlt-1-39',
                                      label='DDLT-1-39',
                                      status='ingebruik',
                                      definitie='DDLT-1-39',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ddlt-1-39'),
        'ddm-8-3441': KeuzelijstWaarde(invulwaarde='ddm-8-3441',
                                       label='DDM-8-3441',
                                       status='ingebruik',
                                       definitie='DDM-8-3441',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ddm-8-3441'),
        'n-100-a80': KeuzelijstWaarde(invulwaarde='n-100-a80',
                                      label='N-100-A80',
                                      status='uitgebruik',
                                      definitie='N-100-A80',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/n-100-a80'),
        'ntk615ba': KeuzelijstWaarde(invulwaarde='ntk615ba',
                                     label='NTK615BA',
                                     status='ingebruik',
                                     definitie='NTK615BA',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ntk615ba'),
        'ntk667ab': KeuzelijstWaarde(invulwaarde='ntk667ab',
                                     label='NTK667AB',
                                     status='ingebruik',
                                     definitie='NTK667AB',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ntk667ab'),
        'ntk669am': KeuzelijstWaarde(invulwaarde='ntk669am',
                                     label='NTK669AM',
                                     status='ingebruik',
                                     definitie='NTK669AM',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ntk669am')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.IVRIComponent import IVRIComponent
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlIVRIMerkITSapp import KlIVRIMerkITSapp
from ...Datatypes.KlIVRIModelITSapp import KlIVRIModelITSapp


# Generated with OTLClassCreator. To modify: extend, do not edit
class ITSapp(IVRIComponent):
    """Functionele software component die de intelligente regel applicaties aanbiedt aan de intelligente verkeersregelaars."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ITSapp'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsSWOnderdeelVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Detectielus', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Sensor', direction='u')  # u = unidirectional

        self._isLokaalGehost = OTLAttribuut(field=BooleanField,
                                            naam='isLokaalGehost',
                                            label='is lokaal gehost',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ITSapp.isLokaalGehost',
                                            definition='Geeft aan of de ITSapp lokaal wordt gehost in plaats van op een virtuele server.',
                                            owner=self)

        self._merk = OTLAttribuut(field=KlIVRIMerkITSapp,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ITSapp.merk',
                                  definition='De merknaam van de ITSapp; duidt op de leverancier of producent van de iVRI component.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlIVRIModelITSapp,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ITSapp.modelnaam',
                                       definition='De modelnaam/product range van de ITSapp.',
                                       owner=self)

    @property
    def isLokaalGehost(self) -> bool:
        """Geeft aan of de ITSapp lokaal wordt gehost in plaats van op een virtuele server."""
        return self._isLokaalGehost.get_waarde()

    @isLokaalGehost.setter
    def isLokaalGehost(self, value):
        self._isLokaalGehost.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """De merknaam van de ITSapp; duidt op de leverancier of producent van de iVRI component."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam/product range van de ITSapp."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlTypeTrekker import KlTypeTrekker
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Trekker(TechnischDocument, AIMNaamObject, LijnGeometrie):
    """Een lineair mechanisch element, dubbelzijdig scharnierend, dat beoogd is om hoofdzakelijk op trek te belasten. Het verbindt, bijvoorbeeld, enerzijds het (bewegend) brugdeel/ beweegbare waterkerende constructie met anderzijds de lastzijde van de balansarm/bovenrolwagen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Trekker'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Lager', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balans', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hefportiek', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Heftoren', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rolwagenchassis', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Bovenrolwagen', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel', direction='o')  # o = direction: outgoing

        self._heeftVerendElement = OTLAttribuut(field=BooleanField,
                                                naam='heeftVerendElement',
                                                label='heeft verend element',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Trekker.heeftVerendElement',
                                                definition='Geeft aan de trekker een verend element heeft of niet.',
                                                owner=self)

        self._type = OTLAttribuut(field=KlTypeTrekker,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Trekker.type',
                                  definition='Het type van de trekker.',
                                  owner=self)

    @property
    def heeftVerendElement(self) -> bool:
        """Geeft aan de trekker een verend element heeft of niet."""
        return self._heeftVerendElement.get_waarde()

    @heeftVerendElement.setter
    def heeftVerendElement(self, value):
        self._heeftVerendElement.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type van de trekker."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AanvaarbeschermingGeleidewerk import AanvaarbeschermingGeleidewerk
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlAanvaarbeschermingType import KlAanvaarbeschermingType
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Aanvaarbescherming(AanvaarbeschermingGeleidewerk, AIMNaamObject):
    """Constructie om te verhinderen dat schepen ergens tegenaan botsen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aanvaarbescherming'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElementAanvaarbeschermingGeleidewerk', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondkeringen', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Fuik', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kelderlandhoofd', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kelderpijler', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Landhoofd', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pijler', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balk', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Dukdalf', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HorizontaleConstructieplaat', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Wand', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingszool', direction='i')  # i = direction: incoming

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aanvaarbescherming.lengte',
                                    definition='De lengte, in meter, van de aanvaarbescherming.',
                                    owner=self)

        self._typeAanvaarbescherming = OTLAttribuut(field=KlAanvaarbeschermingType,
                                                    naam='typeAanvaarbescherming',
                                                    label='type aanvaarbescherming',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aanvaarbescherming.typeAanvaarbescherming',
                                                    usagenote='Attribuut uit gebruik sinds versie 2.14.0',
                                                    deprecated_version='2.14.0',
                                                    definition='De soort van aanvaarbescherming.',
                                                    owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De lengte, in meter, van de aanvaarbescherming."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def typeAanvaarbescherming(self) -> str:
        """De soort van aanvaarbescherming."""
        return self._typeAanvaarbescherming.get_waarde()

    @typeAanvaarbescherming.setter
    def typeAanvaarbescherming(self, value):
        self._typeAanvaarbescherming.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KwantWrdInTon import KwantWrdInTon, KwantWrdInTonWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Portiek(TechnischDocument, AIMNaamObject, PuntGeometrie, LijnGeometrie):
    """Een dragende constructie in de vorm van een omgekeerde (dubbele) U."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Portiek'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ankerplaat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AsMechanisch', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schommeljuk', direction='u')  # u = unidirectional

        self._gewicht = OTLAttribuut(field=KwantWrdInTon,
                                     naam='gewicht',
                                     label='gewicht',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Portiek.gewicht',
                                     definition='Het gewicht, uitgedrukt in kilogram.',
                                     owner=self)

    @property
    def gewicht(self) -> KwantWrdInTonWaarden:
        """Het gewicht, uitgedrukt in kilogram."""
        return self._gewicht.get_waarde()

    @gewicht.setter
    def gewicht(self, value):
        self._gewicht.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlAfdichtingsvoorzieningtype import KlAfdichtingsvoorzieningtype
from ...Datatypes.KlMateriaalAfdichtingsvoorziening import KlMateriaalAfdichtingsvoorziening
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Afdichtingsvoorziening(AIMNaamObject, PuntGeometrie):
    """Voorziening om te zorgen dat er geen water lekt tussen verschillende onderdelen van een beweegbare waterkerende constructie alsook tussen beweegbare en vaste waterbouwkundige constructies."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afdichtingsvoorziening'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aanslagbalk', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#BeweegbareWaterkerendeConstructie', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#TijdelijkeWaterkerendeConstructie', direction='o')  # o = direction: outgoing

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afdichtingsvoorziening.lengte',
                                    definition='De lengte van de afdichtingsvoorziening, uitgedrukt in meter',
                                    owner=self)

        self._materiaalAfdichtingsvoorziening = OTLAttribuut(field=KlMateriaalAfdichtingsvoorziening,
                                                             naam='materiaalAfdichtingsvoorziening',
                                                             label='materiaal afdichtingsvoorziening',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afdichtingsvoorziening.materiaalAfdichtingsvoorziening',
                                                             definition='De verschillende materialen die worden gebruikt voor het maken van afdichtingsvoorzieningen.',
                                                             owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afdichtingsvoorziening.technischeFiche',
                                             definition='De technische fiche van de afdichtingsvoorziening.',
                                             owner=self)

        self._type = OTLAttribuut(field=KlAfdichtingsvoorzieningtype,
                                  naam='type',
                                  label='type afdichtingsvoorziening',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afdichtingsvoorziening.type',
                                  definition='De verschillende types afdichtingsvoorzieningen.',
                                  owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De lengte van de afdichtingsvoorziening, uitgedrukt in meter"""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def materiaalAfdichtingsvoorziening(self) -> str:
        """De verschillende materialen die worden gebruikt voor het maken van afdichtingsvoorzieningen."""
        return self._materiaalAfdichtingsvoorziening.get_waarde()

    @materiaalAfdichtingsvoorziening.setter
    def materiaalAfdichtingsvoorziening(self, value):
        self._materiaalAfdichtingsvoorziening.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de afdichtingsvoorziening."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """De verschillende types afdichtingsvoorzieningen."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlOlieAdditieven(KeuzelijstField):
    """Keuzelijst voor de verschillende additieven die men kan toevoegen aan olie."""
    naam = 'KlOlieAdditieven'
    label = 'Olie additieven'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlOlieAdditieven'
    definition = 'Keuzelijst voor de verschillende additieven die men kan toevoegen aan olie.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlOlieAdditieven'
    options = {
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Verkeersteken import Verkeersteken
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField


# Generated with OTLClassCreator. To modify: extend, do not edit
class VerkeersbordVerkeersteken(Verkeersteken):
    """De voorstelling door middel van een verkeersbord van een aanwijzing ten behoeve van de weggebruikers die verbonden wordt aan het aankondigen of opleggen van een bepaalde verkeersmaatregel zoals bepaald in de wegcode."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VerkeersbordVerkeersteken'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersteken', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VerkeersbordConcept', direction='o')  # o = direction: outgoing

        self._isBeginZone = OTLAttribuut(field=BooleanField,
                                         naam='isBeginZone',
                                         label='is begin van een zone',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VerkeersbordVerkeersteken.isBeginZone',
                                         definition='Duidt aan of het verkeersteken het begin van een zone aanduidt.',
                                         owner=self)

        self._isEindeZone = OTLAttribuut(field=BooleanField,
                                         naam='isEindeZone',
                                         label='is einde van een zone',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VerkeersbordVerkeersteken.isEindeZone',
                                         definition='Duidt aan of het verkeersteken het einde van een zone aanduidt.',
                                         owner=self)

    @property
    def isBeginZone(self) -> bool:
        """Duidt aan of het verkeersteken het begin van een zone aanduidt."""
        return self._isBeginZone.get_waarde()

    @isBeginZone.setter
    def isBeginZone(self, value):
        self._isBeginZone.set_waarde(value, owner=self)

    @property
    def isEindeZone(self) -> bool:
        """Duidt aan of het verkeersteken het einde van een zone aanduidt."""
        return self._isEindeZone.get_waarde()

    @isEindeZone.setter
    def isEindeZone(self, value):
        self._isEindeZone.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.DtcVerankeringDekzerkprofiel import DtcVerankeringDekzerkprofiel, DtcVerankeringDekzerkprofielWaarden
from ...Datatypes.KlConstructiestaalsoort import KlConstructiestaalsoort
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Dekzerkprofiel(AIMNaamObject, PuntGeometrie, LijnGeometrie):
    """Dit zijn stalen voorzieningen bedoeld om hoekige kanten van het verticale vlak met het horizontale vlak van betonconstructies tegen schade te beschermen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dekzerkprofiel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kesp', direction='u')  # u = unidirectional

        self._detailplanDekzerkprofiel = OTLAttribuut(field=DtcDocument,
                                                      naam='detailplanDekzerkprofiel',
                                                      label='detailplan',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dekzerkprofiel.detailplanDekzerkprofiel',
                                                      definition='Het plan van de geometrie van het dekzerkprofiel dat informatie bevat over de ontluchtingsgaten, materiaalkwaliteit, conserveringssysteem en verankeringssysteem.',
                                                      owner=self)

        self._materiaal = OTLAttribuut(field=KlConstructiestaalsoort,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dekzerkprofiel.materiaal',
                                       definition='De verschillende opties van materiaal voor dekzerkprofielen.',
                                       owner=self)

        self._verankering = OTLAttribuut(field=DtcVerankeringDekzerkprofiel,
                                         naam='verankering',
                                         label='verankering',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dekzerkprofiel.verankering',
                                         definition='Bevat informatie m.b.t. het materiaal en type van verankering.',
                                         owner=self)

    @property
    def detailplanDekzerkprofiel(self) -> DtcDocumentWaarden:
        """Het plan van de geometrie van het dekzerkprofiel dat informatie bevat over de ontluchtingsgaten, materiaalkwaliteit, conserveringssysteem en verankeringssysteem."""
        return self._detailplanDekzerkprofiel.get_waarde()

    @detailplanDekzerkprofiel.setter
    def detailplanDekzerkprofiel(self, value):
        self._detailplanDekzerkprofiel.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """De verschillende opties van materiaal voor dekzerkprofielen."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def verankering(self) -> DtcVerankeringDekzerkprofielWaarden:
        """Bevat informatie m.b.t. het materiaal en type van verankering."""
        return self._verankering.get_waarde()

    @verankering.setter
    def verankering(self, value):
        self._verankering.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Geleidingsmechanisme import Geleidingsmechanisme
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlTypeMechanisme import KlTypeMechanisme


# Generated with OTLClassCreator. To modify: extend, do not edit
class Taatsmechanisme(Geleidingsmechanisme, AIMObject):
    """Wordt gebruikt om bouwkundige constructies, zoals een puntdeur, draaideur of draaibrug, te geleiden. De geleiding omvat voornamelijk rotatie en soms ook translatie. Daarnaast vervult het een dragende functie met betrekking tot de sluisdeur."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Taatsmechanisme'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taatspen', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taatspot', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taatsschoen', direction='i')  # i = direction: incoming

        self._isRegelbaar = OTLAttribuut(field=BooleanField,
                                         naam='isRegelbaar',
                                         label='is regelbaar',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Taatsmechanisme.isRegelbaar',
                                         definition='Geeft aan of het taatsmechanisme regelbaar is of niet.',
                                         owner=self)

        self._type = OTLAttribuut(field=KlTypeMechanisme,
                                  naam='type',
                                  label='type mechanisme',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Taatsmechanisme.type',
                                  definition='Geeft de verschillende types taatsmechanismen aan.',
                                  owner=self)

    @property
    def isRegelbaar(self) -> bool:
        """Geeft aan of het taatsmechanisme regelbaar is of niet."""
        return self._isRegelbaar.get_waarde()

    @isRegelbaar.setter
    def isRegelbaar(self, value):
        self._isRegelbaar.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Geeft de verschillende types taatsmechanismen aan."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlPutbekledingType(KeuzelijstField):
    """Types van putbekleding."""
    naam = 'KlPutbekledingType'
    label = 'Putbekleding type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlPutbekledingType'
    definition = 'Types van putbekleding.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlPutbekledingType'
    options = {
        'solventvrije-kunsthars': KeuzelijstWaarde(invulwaarde='solventvrije-kunsthars',
                                                   label='solventvrije kunsthars',
                                                   status='ingebruik',
                                                   definitie='solventvrije kunsthars',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutbekledingType/solventvrije-kunsthars'),
        'solventvrije-vezelversterkte-epoxyhars': KeuzelijstWaarde(invulwaarde='solventvrije-vezelversterkte-epoxyhars',
                                                                   label='solventvrije vezelversterkte epoxyhars',
                                                                   status='ingebruik',
                                                                   definitie='solventvrije vezelversterkte epoxyhars',
                                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutbekledingType/solventvrije-vezelversterkte-epoxyhars')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Classes.Abstracten.Fundering import Fundering
from ...Classes.Abstracten.Grondkeringen import Grondkeringen
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class DamplankAbstracte(Fundering, Grondkeringen, PuntGeometrie):
    """Abstracte om eigenschappen van de damplank te bundelen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#DamplankAbstracte'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Hoppinzuil', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SteunStandaard', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Damwand', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding', direction='i')  # i = direction: incoming

        self._planklengte = OTLAttribuut(field=KwantWrdInMeter,
                                         naam='planklengte',
                                         label='planklengte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#DamplankAbstracte.planklengte',
                                         definition='Lengte van de damplank in meter.',
                                         owner=self)

        self._steek = OTLAttribuut(field=KwantWrdInMeter,
                                   naam='steek',
                                   label='steek',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#DamplankAbstracte.steek',
                                   definition='Geeft de steek van de damplank aan in meter.',
                                   owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#DamplankAbstracte.technischeFiche',
                                             definition='Technische fiche dat de technische details bijhoudt van de damplank.',
                                             owner=self)

    @property
    def planklengte(self) -> KwantWrdInMeterWaarden:
        """Lengte van de damplank in meter."""
        return self._planklengte.get_waarde()

    @planklengte.setter
    def planklengte(self, value):
        self._planklengte.set_waarde(value, owner=self)

    @property
    def steek(self) -> KwantWrdInMeterWaarden:
        """Geeft de steek van de damplank aan in meter."""
        return self._steek.get_waarde()

    @steek.setter
    def steek(self, value):
        self._steek.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """Technische fiche dat de technische details bijhoudt van de damplank."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlStraatkolkBakType(KeuzelijstField):
    """Het type van bak van de straatkolk."""
    naam = 'KlStraatkolkBakType'
    label = 'Straatkolk bak type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlStraatkolkBakType'
    definition = 'Het type van bak van de straatkolk.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlStraatkolkBakType'
    options = {
        'beton': KeuzelijstWaarde(invulwaarde='beton',
                                  label='beton',
                                  status='ingebruik',
                                  definitie='beton',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStraatkolkBakType/beton'),
        'gemetst': KeuzelijstWaarde(invulwaarde='gemetst',
                                    label='gemetst',
                                    status='ingebruik',
                                    definitie='gemetst',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStraatkolkBakType/gemetst'),
        'geprefabriceerde-betonnen-bak-type-I': KeuzelijstWaarde(invulwaarde='geprefabriceerde-betonnen-bak-type-I',
                                                                 label='geprefabriceerde betonnen bak type I',
                                                                 status='ingebruik',
                                                                 definitie='geprefabriceerde betonnen bak type I',
                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStraatkolkBakType/geprefabriceerde-betonnen-bak-type-I'),
        'geprefabriceerde-betonnen-bak-type-II': KeuzelijstWaarde(invulwaarde='geprefabriceerde-betonnen-bak-type-II',
                                                                  label='geprefabriceerde betonnen bak type II',
                                                                  status='ingebruik',
                                                                  definitie='geprefabriceerde betonnen bak type II',
                                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStraatkolkBakType/geprefabriceerde-betonnen-bak-type-II'),
        'gietijzeren-bak': KeuzelijstWaarde(invulwaarde='gietijzeren-bak',
                                            label='gietijzeren bak',
                                            status='ingebruik',
                                            definitie='gietijzeren bak',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStraatkolkBakType/gietijzeren-bak'),
        'infiltratiekolk-type-1': KeuzelijstWaarde(invulwaarde='infiltratiekolk-type-1',
                                                   label='Infiltratiekolk type 1',
                                                   status='ingebruik',
                                                   definitie='Infiltratiekolk type 1',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStraatkolkBakType/infiltratiekolk-type-1'),
        'infiltratiekolk-type-1-2': KeuzelijstWaarde(invulwaarde='infiltratiekolk-type-1-2',
                                                     label='Infiltratiekolk type 1+',
                                                     status='ingebruik',
                                                     definitie='Infiltratiekolk type 1+',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStraatkolkBakType/infiltratiekolk-type-1-2'),
        'infiltratiekolk-type-2': KeuzelijstWaarde(invulwaarde='infiltratiekolk-type-2',
                                                   label='Infiltratiekolk type 2',
                                                   status='ingebruik',
                                                   definitie='Infiltratiekolk type 2',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStraatkolkBakType/infiltratiekolk-type-2')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class CilinderStangkop(TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Het mechanisch onderdeel (oog of vork) dat op het uiteinde van de cilinderstang wordt gemonteerd en de verbinding van de stang met de bewegende constructie realiseert."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#CilinderStangkop'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Lager', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cilinderstang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pen', direction='u')  # u = unidirectional

        self._isOog = OTLAttribuut(field=BooleanField,
                                   naam='isOog',
                                   label='is oog',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#CilinderStangkop.isOog',
                                   definition='Geeft aan of de stangkop uitgevoerd is als oog. In zo een geval wordt de stangkop tussen een gaffel geschoven. In het andere geval is de stangkop zelf een gaffel dat over een oog wordt geschoven.',
                                   owner=self)

    @property
    def isOog(self) -> bool:
        """Geeft aan of de stangkop uitgevoerd is als oog. In zo een geval wordt de stangkop tussen een gaffel geschoven. In het andere geval is de stangkop zelf een gaffel dat over een oog wordt geschoven."""
        return self._isOog.get_waarde()

    @isOog.setter
    def isOog(self, value):
        self._isOog.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Bliksemafleider(AIMNaamObject, PuntGeometrie):
    """Een metalen staaf die zich doorgaans op het hoogste punt van een gebouw of draagconstructie bevindt en in het geval van een blikseminslag een laag-impedant pad naar de bodem voorziet. De bliksem zal dus verkiezen op deze staaf in te slaan, eerder dan op een ander punt van het gebouw of draagconstructie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bliksemafleider'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#EMDraagconstructie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gebouw', direction='u')  # u = unidirectional



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Classes.Abstracten.AfschermendeConstructie import AfschermendeConstructie
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class AansluitendeConstructie(AfschermendeConstructie, LijnGeometrie):
    """Abstracte die alle aansluitende constructies bundelt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AansluitendeConstructie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorvangplank', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AansluitendeConstructie', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Calamiteitendoorsteek', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geleideconstructie', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Obstakelbeveiliger', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Overgangsconstructie', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Calamiteitendoorsteek', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Obstakelbeveiliger', direction='i')  # i = direction: incoming

        self._totaleLengte = OTLAttribuut(field=KwantWrdInMeter,
                                          naam='totaleLengte',
                                          label='totale lengte',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AansluitendeConstructie.totaleLengte',
                                          definition='De totale lengte van de elementen van de aansluitende constructie.',
                                          owner=self)

    @property
    def totaleLengte(self) -> KwantWrdInMeterWaarden:
        """De totale lengte van de elementen van de aansluitende constructie."""
        return self._totaleLengte.get_waarde()

    @totaleLengte.setter
    def totaleLengte(self, value):
        self._totaleLengte.set_waarde(value, owner=self)
